==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/he-IL/admin/hardware/message.php <==
<?php

return [

    'undeployable' 		=> '<strong>Warning: </strong> This asset has been marked as currently undeployable. If this status has changed, please update the asset status.',
    'does_not_exist' 	=> 'הנכס אינו קיים.',
    'does_not_exist_var'=> 'Asset with tag :asset_tag not found.',
    'no_tag' 	        => 'No asset tag provided.',
    'does_not_exist_or_not_requestable' => 'הנכס אינו קיים או לא זמין.',
    'assoc_users'	 	=> 'הנכס הזה מסומן כרגע למשתמש ולא ניתן למחוק אותו. בדוק תחילה את הנכס ולאחר מכן נסה למחוק שוב.',
    'warning_audit_date_mismatch' 	=> 'This asset\'s next audit date (:next_audit_date) is before the last audit date (:last_audit_date). Please update the next audit date.',

    'create' => [
        'error'   		=> 'הנכס לא נוצר, נסה שוב. You',
        'success' 		=> 'הנכס נוצר בהצלחה. :)',
        'success_linked' => 'Asset with tag :tag was created successfully. <strong><a href=":link" style="color: white;">Click here to view</a></strong>.',
    ],

    'update' => [
        'error'   			=> 'הנכס לא עודכן, נסה שוב',
        'success' 			=> 'הנכס עודכן בהצלחה.',
        'encrypted_warning' => 'Asset updated successfully, but encrypted custom fields were not due to permissions',
        'nothing_updated'	=>  'לא נבחרו שדות, ולכן דבר לא עודכן.',
        'no_assets_selected'  =>  'No assets were selected, so nothing was updated.',
        'assets_do_not_exist_or_are_invalid' => 'Selected assets cannot be updated.',
    ],

    'restore' => [
        'error'   		=> 'הנכס לא שוחזר, נסה שוב',
        'success' 		=> 'הנכס שוחזר בהצלחה.',
        'bulk_success' 		=> 'הנכס שוחזר בהצלחה.',
        'nothing_updated'   => 'No assets were selected, so nothing was restored.', 
    ],

    'audit' => [
        'error'   		=> 'Asset audit unsuccessful: :error ',
        'success' 		=> 'ביקורת נכסים נרשמה בהצלחה.',
    ],


    'deletefile' => [
        'error'   => 'הקובץ לא נמחק. בבקשה נסה שוב.',
        'success' => 'הקובץ נמחק בהצלחה.',
    ],

    'upload' => [
        'error'   => 'הקובץ לא הועלה. בבקשה נסה שוב.',
        'success' => 'הקבצים הועלו בהצלחה.',
        'nofiles' => 'לא בחרת קבצים להעלאה, או שהקובץ שאתה מנסה להעלות גדול מדי',
        'invalidfiles' => 'אחד או יותר מהקבצים שלך גדול מדי או שהוא סוג קובץ שאינו מותר. סוגי קבצים מותרים הם png, gif, jpg, doc, docx, pdf ו- txt.',
    ],

    'import' => [
        'import_button'         => 'Process Import',
        'error'                 => 'פריטים מסוימים לא ייבאו כראוי.',
        'errorDetail'           => 'הפריטים הבאים לא יובאו בגלל שגיאות.',
        'success'               => 'הקובץ שלך יובא',
        'file_delete_success'   => 'הקובץ שלך נמחק בהצלחה',
        'file_delete_error'      => 'לא ניתן היה למחוק את הקובץ',
        'file_missing' => 'The file selected is missing',
        'file_already_deleted' => 'The file selected was already deleted',
        'header_row_has_malformed_characters' => 'One or more attributes in the header row contain malformed UTF-8 characters',
        'content_row_has_malformed_characters' => 'One or more attributes in the first row of content contain malformed UTF-8 characters',
    ],


    'delete' => [
        'confirm'   	=> 'האם אתה בטוח שברצונך למחוק את הנכס הזה?',
        'error'   		=> 'היתה בעיה במחיקת הנכס. בבקשה נסה שוב.',
        'nothing_updated'   => 'לא נבחרו נכסים ולכן לא נמחק דבר.',
        'success' 		=> 'הנכס נמחק בהצלחה.',
    ],

    'checkout' => [
        'error'   		=> 'הנכס לא נבדק, נסה שוב',
        'success' 		=> 'הנכס הוצא בהצלחה.',
        'user_does_not_exist' => 'משתמש זה אינו חוקי. בבקשה נסה שוב.',
        'not_available' => 'הנכס הזה אינו זמין לקופה!',
        'no_assets_selected' => 'עליך לבחור לפחות בנכס אחד מהרשימה',
    ],

    'checkin' => [
        'error'   		=> 'הנכס לא נבדק, נסה שוב',
        'success' 		=> 'הנכס נבדק בהצלחה.',
        'user_does_not_exist' => 'משתמש זה אינו חוקי. בבקשה נסה שוב.',
        'already_checked_in'  => 'הנכס כבר נבדק.',

    ],

    'requests' => [
        'error'   		=> 'הנכס לא התבקש, נסה שוב',
        'success' 		=> 'הנכס המבוקש בהצלחה.',
        'canceled'      => 'בקשת התשלום בוטלה בהצלחה',
    ],

];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/he-IL/admin/hardware/message.php <==
<?php

return [

    'undeployable' 		 => '<strong>Warning: </strong> This asset has been marked as currently undeployable. If this status has changed, please update the asset status.',
    'does_not_exist' 	 => 'הנכס אינו קיים.',
    'does_not_exist_var' => 'Asset with tag :asset_tag not found.',
    'no_tag' 	         => 'לא סופק תג נכס.',
    'does_not_exist_or_not_requestable' => 'הנכס אינו קיים או לא זמין.',
    'assoc_users'	 	 => 'הנכס הזה מסומן כרגע למשתמש ולא ניתן למחוק אותו. בדוק תחילה את הנכס ולאחר מכן נסה למחוק שוב.',
    'warning_audit_date_mismatch' 	=> 'This asset\'s next audit date (:next_audit_date) is before the last audit date (:last_audit_date). Please update the next audit date.',
    'labels_generated'   => 'תוויות נוצרו בהצלחה.',
    'error_generating_labels' => 'שגיאה ביצירת תוויות.',
    'no_assets_selected' => 'לא נבחרו נכסים.',

    'create' => [
        'error'   		=> 'הנכס לא נוצר, נסה שוב. You',
        'success' 		=> 'הנכס נוצר בהצלחה. :)',
        'success_linked' => 'נכס עם תג :tag נוצר בהצלחה. <strong><a href=":link" style="color: white;">לחץ כאן לצפייה</a></strong>.',
        'multi_success_linked' => 'Asset with tag :links was created successfully.|:count assets were created succesfully. :links.',
        'partial_failure' => 'An asset was unable to be created. Reason: :failures|:count assets were unable to be created. Reasons: :failures',
    ],

    'update' => [
        'error'   			=> 'הנכס לא עודכן, נסה שוב',
        'success' 			=> 'הנכס עודכן בהצלחה.',
        'encrypted_warning' => 'הנכס עודכן בהצלחה, אבל השדות המותאמים-אישית שמוצפנים לא עודכנו בגלל מחסור בהרשאות',
        'nothing_updated'	=>  'לא נבחרו שדות, ולכן דבר לא עודכן.',
        'no_assets_selected'  =>  'No assets were selected, so nothing was updated.',
        'assets_do_not_exist_or_are_invalid' => 'Selected assets cannot be updated.',
    ],

    'restore' => [
        'error'   		=> 'הנכס לא שוחזר, נסה שוב',
        'success' 		=> 'הנכס שוחזר בהצלחה.',
        'bulk_success' 		=> 'הנכס שוחזר בהצלחה.',
        'nothing_updated'   => 'No assets were selected, so nothing was restored.', 
    ],

    'audit' => [
        'error'   		=> 'Asset audit unsuccessful: :error ',
        'success' 		=> 'ביקורת נכסים נרשמה בהצלחה.',
    ],


    'deletefile' => [
        'error'   => 'הקובץ לא נמחק. בבקשה נסה שוב.',
        'success' => 'הקובץ נמחק בהצלחה.',
    ],

    'upload' => [
        'error'   => 'הקובץ לא הועלה. בבקשה נסה שוב.',
        'success' => 'הקבצים הועלו בהצלחה.',
        'nofiles' => 'לא בחרת קבצים להעלאה, או שהקובץ שאתה מנסה להעלות גדול מדי',
        'invalidfiles' => 'אחד או יותר מהקבצים שלך גדול מדי או שהוא סוג קובץ שאינו מותר. סוגי קבצים מותרים הם png, gif, jpg, doc, docx, pdf ו- txt.',
    ],

    'import' => [
        'import_button'         => 'Process Import',
        'error'                 => 'פריטים מסוימים לא ייבאו כראוי.',
        'errorDetail'           => 'הפריטים הבאים לא יובאו בגלל שגיאות.',
        'success'               => 'הקובץ שלך יובא',
        'file_delete_success'   => 'הקובץ שלך נמחק בהצלחה',
        'file_delete_error'      => 'לא ניתן היה למחוק את הקובץ',
        'file_missing' => 'The file selected is missing',
        'file_already_deleted' => 'The file selected was already deleted',
        'header_row_has_malformed_characters' => 'One or more attributes in the header row contain malformed UTF-8 characters',
        'content_row_has_malformed_characters' => 'One or more attributes in the first row of content contain malformed UTF-8 characters',
    ],


    'delete' => [
        'confirm'   	=> 'האם אתה בטוח שברצונך למחוק את הנכס הזה?',
        'error'   		=> 'היתה בעיה במחיקת הנכס. בבקשה נסה שוב.',
        'nothing_updated'   => 'לא נבחרו נכסים ולכן לא נמחק דבר.',
        'success' 		=> 'הנכס נמחק בהצלחה.',
    ],

    'checkout' => [
        'error'   		=> 'הנכס לא נבדק, נסה שוב',
        'success' 		=> 'הנכס הוצא בהצלחה.',
        'user_does_not_exist' => 'משתמש זה אינו חוקי. בבקשה נסה שוב.',
        'not_available' => 'הנכס הזה אינו זמין לקופה!',
        'no_assets_selected' => 'עליך לבחור לפחות בנכס אחד מהרשימה',
    ],

    'multi-checkout' => [
        'error'   => 'Asset was not checked out, please try again|Assets were not checked out, please try again',
        'success' => 'Asset checked out successfully.|Assets checked out successfully.',
    ],

    'checkin' => [
        'error'   		=> 'הנכס לא נבדק, נסה שוב',
        'success' 		=> 'הנכס נבדק בהצלחה.',
        'user_does_not_exist' => 'משתמש זה אינו חוקי. בבקשה נסה שוב.',
        'already_checked_in'  => 'הנכס כבר נבדק.',

    ],

    'requests' => [
        'error'   		=> 'הנכס לא התבקש, נסה שוב',
        'success' 		=> 'הנכס המבוקש בהצלחה.',
        'canceled'      => 'בקשת התשלום בוטלה בהצלחה',
    ],

];
